%if 0%{?suse_version}
%define daemon_group www
%define apache_service apache2
%define htmlroot /srv/www/htdocs
%define httpconfdir apache2/conf.d
%else
%define daemon_group apache
%define apache_service httpd
%define htmlroot /var/www/html
%define httpconfdir httpd/conf.d
%endif

%define daemon_user monitor
%define daemon_home /opt/monitor
%define daemon_shell /bin/bash
%define daemon_uid 299
%define daemon_group2 sysmon
%define daemon_gid 48

Summary: Core scheduling and checking engine for op5 Monitor
Name: op5-nagios
Epoch: 0
Version: %{op5version}
Release: %{op5release}%{?dist}
License: GPLv2
Group: op5/Monitor
URL: http://www.op5.se
Source0: %name-%version.tar.gz
Prefix: %daemon_home
Requires: sed >= 4.0.9
Requires: monitor-config
BuildRoot: %{_tmppath}/%{name}-%{version}
Obsoletes: monitor <= 4.99.0
Provides: monitor = 6, nagios = %version
BuildRequires: gperf
BuildRequires: perl(Test::Simple)
BuildRequires: perl(Test::Harness)
%if 0%{?suse_version}
Requires: php53
Requires: apache2-mod_php53
#The suse distribution of glibc <= 2.11.3-17.43
#contains a dlclose/dlopen bug which caused globals
#in neb modules to never become unmapped - leading
#to weird behaviour on reload (HUP).
Requires: glibc >= 2.11.3-17.43.1
BuildRequires: apache2-mod_php53
BuildRequires: pwdutils
%else
BuildRequires: shadow-utils
%endif


%description
op5 Monitor is a system for monitoring network hosts and its various
services. It is based on Nagios, inheriting its plugin-driven design
and is thus highly extensible and flexible.

This package contains the op5 version of Nagios, which provides the
core scheduling, checking and notification logic.


%package gui-core
Summary: CGI-based web frontend for op5 Monitor
Group: op5/Monitor
Requires: httpd, %name
Obsoletes: monitor-gui-core
Provides: monitor-gui-core

%description gui-core
This package contains the CGI-based web user interface for op5 Monitor.
It reads the current (or not-so-current) status logs produced by the
monitor core and presents the collected data in a user-friendly way.


%package devel
Summary: Header files and static library stuff for developers
Group: op5/Devel

%description devel
This package contains header files and static libraries used to
develop eventbroker modules and Nagios addons.


%prep
%setup -q


%build
CFLAGS="%optflags -Wall -ggdb3" ./configure \
	--prefix=%prefix \
	--disable-statuswrl \
	--enable-libtap


sed -i '/^INSTALL_OPTS/d;/^COMMAND_OPTS/d' {.,base,cgi}/Makefile

# autofix modification time and program version with each package
sed -i \
	-e 's/^\(#define PROGRAM_VERSION\).*/\1 \"'%version'\"/' \
	-e  's/^\(#define PROGRAM_MODIFICATION_DATE\).*/\1 \"'`date -I`'\"/' \
		include/common.h

%if 0%{?suse_version}
# fix path to webroot
sed -i 's#var/www/html#srv/www/htdocs#g' op5build/authloader.php
# fix http user
sed -i 's#apache#www#' op5build/monitor.init
%endif

%__make nagios cgis
# these tests won't work on op5 systems
rm -f t/622extinfo-local.t t/623cmd-local.t
# we don't build statusmap.cgi, which this test uses
rm -f t/618cgisecurity.t
%__make test


%install
rm -rf %buildroot

for foo in base cgi; do
	pushd $foo && make DESTDIR=%buildroot install-unstripped && popd
done

for foo in commandmode devel; do
	make DESTDIR=%buildroot install-$foo
done

install -Dm755 op5build/monitor.init %buildroot/etc/init.d/monitor
install -Dm640 op5build/httpd.monitor.conf \
	%buildroot/etc/%{httpconfdir}/monitor.conf
install -Dm755 op5build/mondebug.php %buildroot/usr/bin/mondebug
install -Dm755 op5build/mondebug.php %buildroot%prefix/bin/mondebug.php
install -Dm600 op5build/mondebug.cron %buildroot/etc/cron.d/mondebug

install -m 644 op5build/bash_profile.monitor \
	%buildroot%prefix/.bash_profile

# basic directory structure
mkdir -p -m 755 %buildroot%prefix/{share,op5,etc,var}
mkdir -p -m 775 %buildroot%prefix/var/{rw,archives,spool,spool/checkresults}

# core binaries
install -m 755 base/nagios %buildroot%prefix/bin/monitor
install -m 755 base/nagiostats %buildroot%prefix/bin/monitorstats
install -m 755 base/nagiosplit %buildroot%prefix/bin/oconfsplit
install -m 755 base/nagios %buildroot/usr/bin/monitor

# html links and icons
rm -rf html/docs
mkdir -p %buildroot%{htmlroot}
mkdir -p -m 755 %buildroot%daemon_home/share/images/op5tools
cp html/images/op5tools/* %buildroot%daemon_home/share/images/op5tools
chmod 644 %buildroot%daemon_home/share/images/op5tools/*

# op5auth cgi loader files
install -m 644 op5build/authloader.php %buildroot%prefix/share/authloader.php

# op5kad config file
mkdir -p %buildroot%_sysconfdir/op5kad/conf.d
cp op5build/kad.conf %buildroot%_sysconfdir/op5kad/conf.d/monitor.kad

# limits.conf
mkdir -p %buildroot%_sysconfdir/security/limits.d
install -m 644 op5build/limits.conf %buildroot%_sysconfdir/security/limits.d/98-monitor.conf

# Cleanup symlinks we don't use anymore
for link in %{htmlroot}/monitor.old /opt/monitor/share/op5 /opt/monitor/share/cgi-bin; do
	if [ -f $link ]; then
		rm -f $link
	fi
done

%pre
grep -q ^%daemon_group: /etc/group || \
	groupadd -g %daemon_gid %daemon_group

grep -q ^%daemon_group2: /etc/group || \
	groupadd  %daemon_group2

grep -q ^%daemon_user: /etc/passwd || \
	useradd -g %daemon_group -u %daemon_uid -d %daemon_home -s %daemon_shell \
			-M %daemon_user

%if 0%{?suse_version}
usermod -A %daemon_group2 %daemon_user
%else
gpasswd -a %daemon_user %daemon_group
usermod -a -G %daemon_group2 %daemon_user
%endif

%preun
if [ $1 -eq 0 ]; then
	sh /etc/init.d/monitor stop || :
	sh /etc/init.d/monitor slay || :
fi

%post
chkconfig --add monitor
chkconfig monitor on
chkconfig --list monitor

# if necessary, merge pre-4.0 comments into status.dat
if [ -f %daemon_home/var/comment.log ]; then
	echo "Restoring comments from pre-4.0 installation"
	pushd %daemon_home/var >&/dev/null
	/etc/init.d/monitor stop || :
	/etc/init.d/monitor slay || :
	mv comment.log comment.log.merged
	sed -n -e '/^hostcomment/,$p' comment.log.merged | \
		sed -e '/^$/d' -e 's/^[\t ]*//' >> status.sav || :

	# we may have to change the "next_comment_id" thingie in status.sav
	high=$(sed -n 's/^comment_id=//p' status.sav | sort -nr | head -n 1)
	sed -i "s/^next_comment_id=.*/next_comment_id=$high/" status.sav

	popd >&/dev/null
fi

/etc/init.d/monitor start || :

# Remove Nagios 2 vars from configuration file
sed -i \
	-e /^aggregate_status_updates/d \
	-e /^downtime_file/d \
	-e /^comment_file/d \
	-e s/service_reaper_frequency/check_result_reaper_frequency/ \
		%prefix/etc/nagios.cfg

# Remove Nagios 3 vars from configuration file
sed -i \
	-e /^sleep_time/d \
	-e /^command_check_interval/d \
	-e /^enable_failure_prediction/d \
	-e /^enable_embedded_perl/d \
	-e /^use_embedded_perl_implicitly/d \
	-e /^auth_file/d \
	-e /^p1_file/d \
	-e /^external_command_buffer_slots/d \
		%prefix/etc/nagios.cfg

# protect the possibly sensitive data that Monitor harvests.
# Note that the web-user must have read access here
chmod 750 %daemon_home


%post gui-core
# Cleanup symlinks we don't use anymore
for link in /opt/monitor/op5/ninja/cgi-bin /opt/monitor/op5/ninja/css  /opt/monitor/op5/ninja/GraphXML.dtd /opt/monitor/op5/ninja/images /opt/monitor/op5/ninja/js; do
	if [ -f $link ]; then
		rm -f $link
	fi
done

/etc/init.d/%{apache_service} stop || :
/etc/init.d/%{apache_service} start || :

/etc/init.d/monitor stop || :
/etc/init.d/monitor slay || :
/etc/init.d/monitor start || :

%files
%defattr(-,%daemon_user,%daemon_group)
/etc/init.d/monitor
%dir %prefix
/usr/bin/mondebug
%attr(600,root,root) /etc/cron.d/mondebug
%prefix/bin
%attr(775,%daemon_user,%daemon_group) %prefix/var
%attr(775,%daemon_user,%daemon_group) %prefix/var/rw
%attr(775,%daemon_user,%daemon_group) %prefix/var/archives
%attr(775,%daemon_user,%daemon_group) %prefix/var/spool
%attr(775,%daemon_user,%daemon_group) %prefix/var/spool/checkresults
%config(noreplace) %prefix/.bash_profile
%doc README Changelog INSTALLING LEGAL LICENSE UPGRADING
%_sysconfdir/op5kad/conf.d/monitor.kad
%_sysconfdir/security/limits.d/*.conf
/usr/bin/monitor
%dir /opt/monitor/op5

%files gui-core
%defattr(-,root,root)
%config(noreplace) %attr(644,root,root) /etc/%{httpconfdir}/monitor.conf
%attr(755,root,root) %prefix/sbin
%prefix/share


%files devel
%defattr(-,root,root)
%prefix/include/nagios
%prefix/lib/libnagios.a

%clean
rm -rf %buildroot

%changelog
* Fri Nov 2 2007 Andreas Ericsson <ae@op5.se>
- Package op5-specific files and upstream nagios stuff separately.
